import json

from friday import content_type, PYTHON3, POST, status_bad_request, status_not_found, \
    status_created
from functions import byte_to_string, get_datastore, generate_pay_id

if PYTHON3:
    from html import escape
else:
    from cgi import escape


def load_admin_routes(wsgi_application=None):
    @wsgi_application.route("/verify", methods=['POST'])
    def verify_request(request, response):
        datastore = get_datastore()
        response.content_type = content_type['json']

        try:
            data = POST(request.environ)

            if PYTHON3:

                mdict = byte_to_string(data.parameters)

                request_id = str(escape(mdict['request_id'])).strip()
                phone_number = str(escape(mdict['phone_number'])).strip()
                package_name = str(escape(mdict['package_name'])).strip()
                sku = str(escape(mdict['sku'])).strip()
                period = str(escape(mdict['period'])).strip()
                amount = str(escape(mdict['amount'])).strip()

            else:
                request_id = str(escape(data.parameter('request_id')[0])).strip()
                phone_number = str(escape(data.parameter('phone_number')[0])).strip()
                sku = str(escape(data.parameter('sku')[0])).strip()
                period = str(escape(data.parameter('period')[0])).strip()
                package_name = str(escape(data.parameter('package_name')[0])).strip()
                amount = str(escape(data.parameter('amount')[0])).strip()

        except Exception as e:
            print(e)
            result = {'status': status_bad_request}
            response.content = json.dumps(result)

        else:

            # check if request exists
            sql = "select * from requests where request_id = %s and phone_number = %s"
            parameters = [request_id, phone_number]

            data = datastore.select_one(query=sql, parameters=parameters)

            if data:

                # update period, amount, approved ,payid

                sql = "update requests set period = %s, amount = %s, approved = %s, pay_id = %s where request_id = %s and phone_number = %s and sku = %s and package_name = %s and approved = %s"

                pay_id = generate_pay_id()
                parameters = [period, amount, 'Y', pay_id, request_id, phone_number, sku, package_name, 'N']

                result = datastore.update(query=sql, parameters=parameters)

                if result == 'update failed':
                    data['created'] = data['created'].strftime('%Y-%m-%d %H:%M:%S')
                    content = {'status': status_not_found,
                               'message': 'Update failed, request has been approved %s ' % data}

                elif result == 'update successful':

                    content = {'status': status_created,
                               'pay_id': pay_id
                               }

                else:
                    content = {'status': status_not_found,
                               'message': 'Error executing query'
                               }

                response.content = json.dumps(content)


            else:
                message = 'No records found for request_id = %s and phone_number = %s' % (request_id, phone_number)
                content = {'status': status_not_found,
                           'message': message}

            response.content = json.dumps(content)
